<?php

namespace Drp\LdapAuthentication;

use adLDAP\adLDAP;
use adLDAP\adLDAPException;

/**
 * Class Connector
 * @package Drp\LdapAuthentication
 */
class Connector extends adLDAP implements LdapConnector
{

    /**
     * Default Constructor
     * Tries to bind to the AD domain over LDAP or LDAPs
     * @param array $options Array of options to pass to the constructor
     * @throws \adLDAP\adLDAPException
     * @throws adLDAPException
     */
    function __construct($options = array())
    {

        // You can specifically overide any of the default configuration options setup above
        if (count($options) > 0) {

            if (array_key_exists("account_suffix", $options)) {
                $this->accountSuffix = $options["account_suffix"];
            }
            if (array_key_exists("base_dn", $options)) {
                $this->baseDn = $options["base_dn"];
            }
            if (array_key_exists("domain_controllers", $options)) {
                if (!is_array($options["domain_controllers"])) {
                    throw new adLDAPException('[domain_controllers] option must be an array');
                }
                $this->domainControllers = $options["domain_controllers"];
            }
            if (array_key_exists("admin_username", $options)) {
                $this->adminUsername = $options["admin_username"];
            }
            if (array_key_exists("admin_password", $options)) {
                $this->adminPassword = $options["admin_password"];
            }
            if (array_key_exists("real_primarygroup", $options)) {
                $this->realPrimaryGroup = $options["real_primarygroup"];
            }
            if (array_key_exists("use_ssl", $options)) {
                $this->setUseSSL($options["use_ssl"]);
            }
            if (array_key_exists("use_tls", $options)) {
                $this->useTLS = $options["use_tls"];
            }
            if (array_key_exists("recursive_groups", $options)) {
                $this->recursiveGroups = $options["recursive_groups"];
            }
            if (array_key_exists("follow_referrals", $options)) {
                $this->followReferrals = $options["follow_referrals"];
            }
            if (array_key_exists("ad_port", $options)) {
                $this->setPort($options["ad_port"]);
            }
            if (array_key_exists("sso", $options)) {
                $this->setUseSSO($options["sso"]);
                if (!$this->ldapSaslSupported()) {
                    $this->setUseSSO(false);
                }
            }
        }

        if ($this->ldapSupported() === false) {
            throw new adLDAPException('No LDAP support for PHP.  See: http://www.php.net/ldap');
        }

        return $this;
    }

}