<?php

namespace Drp\LdapAuthentication\Providers;

use Illuminate\Foundation\Support\Providers\AuthServiceProvider as ServiceProvider;
use Drp\LdapAuthentication\LdapConnector;
use Drp\LdapAuthentication\Connector;
use adLDAP\adLDAP;

/**
 * Class AuthServiceProvider
 * @package Drp\LdapAuthentication\Providers
 */
class AuthServiceProvider extends ServiceProvider
{

    /**
     * The policy mappings for the application.
     * @var array
     */
    protected $policies = [
    ];

    /**
     * Register any application authentication / authorization services.
     */
    public function boot()
    {
        $this->registerProviders();
        $this->registerLdap();

    }

    /**
     *
     */
    private function registerLdap()
    {

        $this->app->bind(LdapConnector::class, function () {
            return $this->instantiateLdap();
        });

    }

    /**
     * @return adLDAP
     */
    function instantiateLdap()
    {
        // Get config for LDAP
        $config = config('ldap');

        // Attempt to fix issue where LDAP server won't connect until Apache restart: 'Bind to Active Directory
        // failed. Check the login credentials an
        //d/or server details. AD said: Can't contact LDAP server'
        // http://serverfault.com/questions/635090/apache-php-ldap-stops-working-requires-restart-of-apache
        if (true == \Config::get('app.debug')) {
            putenv('LDAPTLS_REQCERT=never');
        }

        return new Connector($config);

    }

    /**
     *
     */
    protected function registerProviders()
    {

        $this->app['auth']->provider('ldap', function ($app) {

            $model = $this->getModel($app);

            return new LdapUserProvider(
                $model,
                $app->make(LdapConnector::class),
                $app->config->get('ldap.groups')
            );
        });
    }

    /**
     * @param $app
     * @return mixed
     */
    protected function getModel($app)
    {
        $provider = $app->config->get('ldap.provider');

        if(empty($provider)){
            throw new \InvalidArgumentException('You must provide a provider name in your LDAP config');
        }

        //Get the model from the provider
        $model = $app->config->get('auth.providers.' . $provider . '.model');

        if (empty($model)) {
            throw new \InvalidArgumentException('You must provide a model for Ldap to return');
        }

        return $model;
    }
}
